# complexity and aging experiment
# 30 young and 30 old participants



library(lme4)
library(lattice)
library(MASS)
library(plyr) 

rm(list=ls())

datafile = read.csv(file.choose(), sep = ",", dec = ".")

colnames(datafile)

##################################################################

col.subject = 1      # specify which column your participant number is in
col.condition = 5     #specify which column contains your condition number
col.stim = 2
crit = 3             # setting the criterium value you want, usually 3 or 2.5 standard deviations

# choose dependent variable
measure = "FFD"

# add to dataframe
datafile$depvar = datafile[,measure]

############

# Work out which colums the fixed and random factors are in

datafile$pp = datafile[,col.subject]
datafile$condition = datafile[,col.condition]
datafile$stim = datafile[,col.stim]

# Let's make sure all the variables are from the correct class
datafile$depvar = as.numeric(datafile$depvar)
datafile$pp = as.factor(datafile$pp)
datafile$stim = as.factor(datafile$stim)
datafile$condition = as.factor(datafile$condition)


#################
# Global measures
#################

# table of means for Age
(table2 <- ddply(datafile, .(Age), summarise, M=mean(depvar, na.rm = TRUE), SD=sd(depvar, na.rm = TRUE), N=length(depvar[!is.na(depvar)]), SE=SD/sqrt(N) ))

#SLIDING CONTRASTS 
contrasts(datafile$Age) <- contr.sdif(2)

# Do we need to log transform?
qqnorm(datafile$depvar)
qqnorm(log(datafile$depvar))

# If yes
datafile$depvar = log(datafile$depvar)

##############################################################
# Main effect age

depvar.lmer = lmer(depvar ~ Age + (1|Participant) + (1|Item), datafile)
summary(depvar.lmer, corr = FALSE)

##############################################################




################
# local analyses
################

# table of means for Complexity
(table1 <- ddply(datafile, .(Complexity), summarise, M=mean(depvar, na.rm = TRUE), SD=sd(depvar, na.rm = TRUE), N=length(depvar[!is.na(depvar)]), SE=SD/sqrt(N)))

# table of means for Age
(table2 <- ddply(datafile, .(Age), summarise, M=mean(depvar, na.rm = TRUE), SD=sd(depvar, na.rm = TRUE), N=length(depvar[!is.na(depvar)]), SE=SD/sqrt(N) ))

# table of means for target
(table3 <- ddply(datafile, .(Age, Complexity), summarise, M=mean(depvar, na.rm = TRUE), SD=sd(depvar, na.rm = TRUE), N=length(depvar[!is.na(depvar)]), SE=SD/sqrt(N) ))


#SLIDING CONTRASTS
contrasts(datafile$Complexity) <- contr.sdif(2)  
contrasts(datafile$Age) <- contr.sdif(2)

# Do we need to log transform?
qqnorm(datafile$depvar)
qqnorm(log(datafile$depvar))

# If yes
datafile$depvar = log(datafile$depvar)

############################################

# Age, Complexity, age x Complexity (1,0)

depvar.lmer = glmer(depvar ~ Age * Complexity + (1|Participant) + (1|Item), datafile, family = binomial)
summary(depvar.lmer, corr = FALSE)



# Age, Complexity, age x Complexity (normal)
depvar.lmer = lmer(depvar ~ Age * Complexity  + (1+Complexity|Participant) + (1+Complexity|Item), datafile)
summary(depvar.lmer, corr = FALSE)


####################################################################

# Investigate interactions between age and complexity

# Contrast matrix for AgeComplexity
contrast.matrix <- matrix(c(   
  -1, +1, 0, 0,        # old high vs low
  0, 0, -1, +1), 4, 2, # young high vs low
                      dimnames=list(c("a1_H", "a1_L", "a2_H", "a2_L"), 
                                    c("a1_HvsL", "a2_HvsL")))

# Perform some magic (needs to inverse it before assigning to the contrasts)
inv.contrast.matrix <- matrix(t(ginv(contrast.matrix)), 4, 2,
                              dimnames=list(c("a1_H", "a1_L", "a2_H", "a2_L"), 
                                            c("a1_HvsL", "a2_HvsL")))
(contrasts(datafile$Condition) <- fractions(inv.contrast.matrix))

depvar.lmerAgeComplexity = lmer(depvar ~ Condition + (1+Complexity|Participant) + (1+Complexity|Item), datafile)
summary(depvar.lmerAgeComplexity, corr = FALSE)



